/****************************************************************************
 **
 **  Copyright (C) 2007 by Helge Kortendieck, qvtwfc@kasmithee.de
 **
 **  fcs, flash card session, set/unset qvtwfc.desktop into autostart dirs
 **  of KDE, GNOME and xfce4 to define whether a flash card session is to be
 **  started when starting a desktop session
 **
 ** This file may be used under the terms of the GNU General Public
 ** License version 2.0 or later as published by the Free Software Foundation
 **
 ** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 ** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 **
 ****************************************************************************/

#include "fcs.h"


fcs::fcs( QObject *parent ) : QObject( parent )
{
  sFOrig = "/usr/share/applications/qvtwfc-t.desktop";    // orig qvtwcf.desktop file location (acc. debian), static for now
  sHome = QDir::homePath() + "/";
  sFKde = sHome + ".kde/Autostart/qvtwfc-t.desktop";      // full path and name to qvtwfc.desktop file in KDE autostart dir
  sFGnome = sHome + ".config/autostart/qvtwfc-t.desktop"; // full path and name to qvtwfc.desktop file in GNOME autostart dir
  check();                                                // check for supported installed desktops at start
}

fcs::~fcs()
{
}

void fcs::check()                 // check for available desktops
{
  bKde = false;
  bGnome = false;
  errClear();

  QFileInfo fi( sHome + ".kde" );
  if( fi.exists() ) {             // found KDE
    bKde = true;
  }

  QFileInfo fi2( sHome + ".gnome2" );
  if( fi2.exists() ) {            // found GNOME
    bGnome = true;
  }

}

void fcs::state()                 // check available desktops if qvtwfc.desktop is present in their autostart dirs
{
  bKdeSet = false;
  bGnomeSet = false;

  if( bKde ) {
    QFileInfo fi( sFKde );
    if( fi.exists() ) {           // qvtwfc will currently start with KDE session
      bKdeSet = true;
    }
  }

  if( bGnome ) {
    QFileInfo fi2( sFGnome );
    if( fi2.exists() ) {           // qvtwfc will currently start with KDE session
      bGnomeSet = true;
    }
  }

  emit sigState( bKde, bKdeSet, bGnome, bGnomeSet, sErrTit, sErrTxt, iErr );
  errClear();
}

void fcs::set()                   // place qvtwfc.desktop into autostart dir to start it with desktop session
{
  errClear();

  QFile f( sFOrig );
  if( f.exists() ) {              // original qvtwfc.desktop file found

    if( bKde ) {                  // set starting with KDE session
      if( !f.copy( sFKde ) ) {
        iErr = 2;
      }
    }

    if( bGnome ) {                // set starting with GNOME session
      if( !f.copy( sFGnome ) ) {
        iErr = iErr + 4;
      }
    }

  } else {                        // original qvtwfc.desktop file not found
    iErr = 1;
  }

  err();
}

void fcs::unset()                 // delete qvtwfc.desktop from autostart dir so it will not start with desktop session
{
  errClear();

  if( bKde ) {                    // remove starting with KDE session
    QFile f( sFKde );
    if( !f.remove() ) {
      iErr = 8;
    }
  }

  if( bGnome ) {                  // remove starting with GNOME session
    QFile f2( sFGnome );
    if( !f2.remove() ) {
      iErr = iErr + 16;
    }
  }

  err();
}

void fcs::errClear()               // clear error code and text
{
  iErr = 0;
  sErrTit = "";
  sErrTxt = "";
}

void fcs::err()
{
  sErrTxt = "";
  if( iErr < 8 ) {
    sCpDel = tr( "copy" );
    sErrTit = tr( "Error - while setting program to start with session" );
  } else {
    sCpDel = tr( "delete" );
    sErrTit = tr( "Error - while setting program to NOT start with session" );
  }

  sCpKde = tr( "Could not %1 the qvtwfc.desktop file into your KDE session autostart folder: \n"
               "~/.kde/Autostart\n \n" ).arg( sCpDel );
  sCpGnome = tr( "Could not %1 the qvtwfc.desktop file into your GNOME session autostart folder: \n"
                 "~/.gnome2/Autostart\n \n" ).arg( sCpDel );
  sCpStr = tr( "Strange, you may want to check the directories access permission !" );

  switch( iErr ) {
    case 0:                                             // no error
      break;
    case 1:                                             // qvtwfc.desktop file not found when trying to set
      sErrTxt = tr( "Could not find the file qvtwfc.desktop to copy it into your desktop(s) autostart folder.\n"
                    "Full path and name is:\n"
                    "%1\n \n"
                    "This might be a distribution problem, qvtwfc was developed under debian.\n"
                    "If you can locate this file on your machine, you can manually place it in your desktop "
                    "autostart folder:\n"
                    "~/.kde/Autostart for KDE and/or\n"
                    "~/.config/autostart for GNOME.").arg( sFOrig );
      break;

    case 2:                                             // copy to ~/.kde/Autostart failed
      sErrTxt = sCpKde + sCpStr;
      break;
    case 4:                                             // copy to ~/.config/autostart failed
      sErrTxt = sCpGnome + sCpStr;
      break;
    case 6:                                             // copy to ~/.kdeAutostart&.config/autostart failed
      sErrTxt = sCpKde + sCpGnome + sCpStr;
      break;

    case 8:                                             // delete in ~/.kde/Autostart failed
      sErrTxt = sCpKde + sCpStr;
      break;
    case 16:                                            // delete in ~/.config/autostart failed
      sErrTxt = sCpGnome + sCpStr;
      break;
    case 24:                                            // delete in ~/.kde/Autostart&.config/autostart failed
      sErrTxt = sCpKde + sCpGnome + sCpStr;
      break;
  }

  state();
}


#include "fcs.moc"
